```wmd-options
language = es
title_i18n = Kanvas_title_settings
title_text = Configuración - Kanvas
```

<!-- [[wmd]] -->

#### Configuración

La configuración e esta librería se establece a la hora de construir la misma, aunque sí es cierto que a posteriori, en caliente, los atributos pueden ir modificándose. Para establecer la configuración inicial tendríamos la siguiente forma:

```js

/** @type {AnP} */
const anp = new AnP({
    globals : {
        anp_root : "https://anp.k3y.pw"
    }, 
    callback : () => {

        /** @type {Kanvas} */
        const kanvas = new Kanvas(anp, {
            position : "body", 
            autocreate : true, 
            quality : 1, 
            base_x : .5, 
            base_y : .5, 
            cells : 40, 
            autostart : true
        });

    }
});

```

> [!#] En el ejemplo se muestran las configuraciones por defecto del inicio del sistema, pero no son los únicos parámetros.

Los parámetros de configuración que hay serían los siguientes:

[|
|=  Campo       | Tipado                | Obligatorio   | Valor por defecto | Descripción
|   position    | "String|HTMLElement"  | Sí            | '"body"'          | "
                                                                                Sería el selector del elemento donde se quiera instalar por defecto el elemento HTML Canvas o bien, el propio elemento de forma directa.
                                                                              "
|   autocreate  | Boolean               | Sí            | true              | "
                                                                                Determina si se autocrea el elemento HTML Canvas en la posición dada por defecto o no.
                                                                              "
|   quality     | "Integer|Float"       | Sí            | 1                 | "
                                                                                Valor entero o decimal comprendido entre 0 y 1 sin cubrir nunca el valor 0 y determina porcentualmente la calidad de la imagen resultante. *Si se pone un valor superior a 1 o inferior a 0 éstos serán equivalentes a la máxima y a la mínima consecutivamente.*
                                                                              "
|   base_x      | "Integer|Float"       | Sí            | .5                | "
                                                                                Valor entero o decimal comprendido entre 0 y 1, ambos inclusive, el cual determina la posición porcentual de donde establecer el origen en el eje X de los elementos a visualizar en pantalla. Dicho valor puede exceder el valor dado quedando fuera del marco principal de pantalla, el origen en el eje X de los elementos a visualizar en pantalla.
                                                                              "
|   base_y      | "Integer|Float"       | Sí            | .5                | "
                                                                                Valor entero o decimal comprendido entre 0 y 1, ambos inclusive, el cual determina la posición porcentual de donde establecer el origen en el eje Y de los elementos a visualizar en pantalla. Dicho valor puede exceder el valor dado quedando fuera del marco principal de pantalla, el origen en el eje Y de los elementos a visualizar en pantalla.
                                                                              "
|   cells       | Integer               | Sí            | 40                | "
                                                                                Valor numérico entero positivo en el cual se indica el número de celdas en el que se divide la pantalla de muestreo principal de los elementos a visualizar.
                                                                              "
|   autostart   | Boolean               | Sí            | true              | Determina si el objeto Kanvas o no.
|   class       | String                | No            |                   | Establece valores de clase al elemento HTML Canvas.
|   git         | String                | No            |                   | "
                                                                                Establece la dirección del proyecto Git como atributo del elemento HTML Canvas.
                                                                            "
|   link        | String                | No            |                   | "
                                                                                Establece la dirección URL del proyecto como atributo del elemento HTML Canvas.
                                                                            "
|]

Es importante tener en cuenta que estos parámetros sólo afectan única y exclusivamente a Kanvas, pero al estar basado en AnP, ciertos comportamientos se condicionan a AnP, como puede ser la frecuencia de refresco del hilo de procesos del que cuelga el funcionamiento del mismo, que es el parámetro de configuración ***fps*** o ***frames_per_second*** del mismo.

<!-- [[wmd]] -->